@@ -94,7 +94,7 @@ class LiteScopeAnalyzerDriver:
                         v <<= 4 if mx is not None else 1
                         m <<= 4 if mx is not None else 1
                         if c != "x":
-                            v |= int(c)
+                            v |= int(c, 16 if mx is not None else 2 )
                             m |= 0xf if mx is not None else 0b1
                     value |= getattr(self, k + "_o")*v
                     mask  |= getattr(self, k + "_m") & (getattr(self, k + "_o")*m)
@@ -134,6 +134,13 @@ class LiteScopeAnalyzerDriver:
         self.storage_enable.write(1)
         self.trigger_enable.write(1)
 
+    def clear(self):
+        self.data = DumpData(self.data_width)
+        self.offset = 0
+        self.length = None
+        self.trigger_enable.write(0)
+        self.storage_enable.write(0)
+
     def done(self):
         return self.storage_done.read()
 
@@ -168,6 +175,8 @@ class LiteScopeAnalyzerDriver:
             dump = CSVDump()
         elif ext == ".py":
             dump = PythonDump()
+        elif ext == ".json":
+            dump = JSONDump()
         elif ext == ".sr":
             dump = SigrokDump(samplerate=samplerate)
         else:
